@@ -68,21 +68,21 @@ fn parse_argument(input: &str) -> IResult<&str, Argument> {
 
 pub fn parse_fmt_spec(input: &str) -> IResult<&str, FormatSlot> {
     // NOTE: macros, maybe?
-    let (input, arg) = if let (new_input, Some(ident)) = opt(parse_argument)(input)? {
-        (new_input, Some(ident))
+    let (input, arg) = if let (input, Some(ident)) = opt(parse_argument)(input)? {
+        (input, Some(ident))
     } else {
         (input, None)
     };
-    let (input, fmt_spec) = if let (new_input, Some(_)) = opt(tag(":"))(input)? {
-        let (new_input, fill) = if let (new_new_input, Some(fill)) = opt(anychar)(new_input)? {
-            (new_new_input, Some(fill))
+    let (input, fmt_spec) = if let (input, Some(_)) = opt(tag(":"))(input)? {
+        let (input, fill) = if let (input, Some(fill)) = opt(anychar)(input)? {
+            (input, Some(fill))
         } else {
-            (new_input, None)
+            (input, None)
         };
-        let (new_input, align) =
-            if let (new_new_input, Some(align)) = opt(one_of("<^>"))(new_input)? {
+        let (input, align) =
+            if let (input, Some(align)) = opt(one_of("<^>"))(input)? {
                 (
-                    new_new_input,
+                    input,
                     Some(match align {
                         '<' => Align::Left,
                         '^' => Align::Center,
@@ -93,11 +93,11 @@ pub fn parse_fmt_spec(input: &str) -> IResult<&str, FormatSlot> {
                     }),
                 )
             } else {
-                (new_input, None)
+                (input, None)
             };
-        let (new_input, sign) = if let (new_new_input, Some(sign)) = opt(one_of("+-"))(new_input)? {
+        let (input, sign) = if let (input, Some(sign)) = opt(one_of("+-"))(input)? {
             (
-                new_new_input,
+                input,
                 Some(match sign {
                     '+' => Sign::Positive,
                     '-' => Sign::Negative,
@@ -107,56 +107,56 @@ pub fn parse_fmt_spec(input: &str) -> IResult<&str, FormatSlot> {
                 }),
             )
         } else {
-            (new_input, None)
+            (input, None)
         };
-        let (new_input, alternate) = if let (new_new_input, Some(_)) = opt(tag("#"))(new_input)? {
-            (new_new_input, true)
+        let (input, alternate) = if let (input, Some(_)) = opt(tag("#"))(input)? {
+            (input, true)
         } else {
-            (new_input, false)
+            (input, false)
         };
-        let (new_input, pad_with_zeros) =
-            if let (new_new_input, Some(_)) = opt(tag("0"))(new_input)? {
-                (new_new_input, true)
+        let (input, pad_with_zeros) =
+            if let (input, Some(_)) = opt(tag("0"))(input)? {
+                (input, true)
             } else {
-                (new_input, false)
+                (input, false)
             };
-        let (new_input, width) = if let (new_new_input, Some(width)) = opt(parse_count)(new_input)?
+        let (input, width) = if let (input, Some(width)) = opt(parse_count)(input)?
         {
-            (new_new_input, Some(width))
+            (input, Some(width))
         } else {
-            (new_input, None)
+            (input, None)
         };
-        let (new_input, percision) = if let (new_new_input, Some(_)) = opt(tag("."))(new_input)? {
-            let new_input = new_new_input;
-            if let (new_new_input, Some(percision)) = opt(parse_count)(new_input)? {
-                (new_new_input, Some(Percision::Count(percision)))
-            } else if let (new_new_input, Some(_)) = opt(tag("*"))(new_input)? {
-                (new_new_input, Some(Percision::SpecifiedPercision))
+        let (input, percision) = if let (input, Some(_)) = opt(tag("."))(input)? {
+            let input = input;
+            if let (input, Some(percision)) = opt(parse_count)(input)? {
+                (input, Some(Precision::Count(percision)))
+            } else if let (input, Some(_)) = opt(tag("*"))(input)? {
+                (input, Some(Precision::SpecifiedPrecision))
             } else {
-                (new_input, None)
+                (input, None)
             }
         } else {
-            (new_input, None)
+            (input, None)
         };
-        let (new_input, kind) =
-            if let (new_new_input, Some(kind)) = opt(one_of("?oxXpbeE"))(new_input)? {
+        let (input, kind) =
+            if let (input, Some(kind)) = opt(one_of("?oxXpbeE"))(input)? {
                 match kind {
                     'x' => {
-                        if let (new_new_new_input, Some(_)) = opt(tag("?"))(new_new_input)? {
-                            (new_new_new_input, Type::DebugLowerHex)
+                        if let (input, Some(_)) = opt(tag("?"))(input)? {
+                            (input, Type::DebugLowerHex)
                         } else {
-                            (new_new_input, Type::LowerHex)
+                            (input, Type::LowerHex)
                         }
                     }
                     'X' => {
-                        if let (new_new_new_input, Some(_)) = opt(tag("?"))(new_new_input)? {
-                            (new_new_new_input, Type::DebugUpperHex)
+                        if let (input, Some(_)) = opt(tag("?"))(input)? {
+                            (input, Type::DebugUpperHex)
                         } else {
-                            (new_new_input, Type::UpperHex)
+                            (input, Type::UpperHex)
                         }
                     }
                     _ => (
-                        new_new_input,
+                        input,
                         match kind {
                             '?' => Type::Debug,
                             'o' => Type::Octal,
@@ -171,10 +171,10 @@ pub fn parse_fmt_spec(input: &str) -> IResult<&str, FormatSlot> {
                     ),
                 }
             } else {
-                (new_input, Type::None)
+                (input, Type::None)
             };
         (
-            new_input,
+            input,
             Some(FormatSpec {
                 fill,
                 align,
@@ -306,9 +306,9 @@ pub enum Count {
 }
 
 #[derive(Debug, PartialEq, Eq)]
-pub enum Percision {
+pub enum Precision {
     Count(Count),
-    SpecifiedPercision,
+    SpecifiedPrecision,
 }
 
 #[derive(Debug, PartialEq, Eq)]
@@ -334,7 +334,7 @@ pub struct FormatSpec {
     pub alternate: bool,
     pub pad_with_zeros: bool,
     pub width: Option<Count>,
-    pub percision: Option<Percision>,
+    pub percision: Option<Precision>,
     pub kind: Type,
 }
 
