@@ -1,5 +1,5 @@
 use parse_fmt_str::{
-    parse_fmt_str, Align, Argument, Count, Percision, PossibleFormatSlot, Sign, Type,
+    parse_fmt_str, Align, Argument, Count, Precision, PossibleFormatSlot, Sign, Type,
 };
 
 #[test]
@@ -87,7 +87,7 @@ fn all_in_one() {
             });
             assert_eq!(
                 fmt_spec.percision.as_ref().unwrap(),
-                &Percision::SpecifiedPercision
+                &Precision::SpecifiedPrecision
             );
             assert_eq!(fmt_spec.kind, Type::DebugUpperHex);
             true
